@@ -312,7 +312,7 @@ simulate_rules <- function(object,
     sim_cmd = paste0(c(preamble,
                      paste0("sim = rxode2::rxSolve(object, params=subjects, events=ev", rx_options_str, ")")),
                      collapse="\n")
-    tcres = FM_tc(
+    tcres = formods::FM_tc(
       cmd     = sim_cmd,
       capture = c("sim"),
       tc_env  = list(object   = object,
@@ -320,6 +320,13 @@ simulate_rules <- function(object,
                      ev       = init_ev))
 
 
+    # After initilization we set the initial conditions to be zero so they 
+    # don't impact the interval simulations 
+    for(sname in object$props$output$state){
+      cmd = paste0("object = object |> model({", sname, "(0) = 0.0})")
+      eval(parse(text=cmd))
+    }
+
     # Incrementing progress bar
     if(!is.null(pbo)){
       cli::cli_progress_update(id=pbo)
@@ -382,12 +389,15 @@ simulate_rules <- function(object,
           ud_history  = NULL
 
           # Now for each subject we apply the rules that are triggered
+          # This will be a dataframe that tracks the rule flags for the 
+          # current event time
+          et_rule_flags = NULL
           for(sub_id in sub_ids){
             # Subject output times during this interval:
             sub_ot          = c()
             # Values of the rules after condition is evaluated during this
             # interval:
-            sub_rule_flags  = list()
+            sub_rule_flags  = list(id=sub_id)
 
             # This will hold any rule actions overwriting the states during
             # this interval. This will overwrite the previous steady-state
@@ -429,7 +439,7 @@ simulate_rules <- function(object,
                                      preamble,
                                      paste0("condition = ", rules[[rule_id]][["condition"]]), collapse="\n"))
                   tcres =
-                    FM_tc(tc_env  = tc_env,
+                    formods::FM_tc(tc_env  = tc_env,
                           capture = c("condition"),
                           cmd     = cmd)
 
@@ -461,7 +471,7 @@ simulate_rules <- function(object,
                         tc_env[["SI_ud_history"]]  = ud_history
 
                         tcres =
-                           FM_tc(tc_env  = tc_env,
+                           formods::FM_tc(tc_env  = tc_env,
                                  capture = capture,
                                  cmd     = cmd)
 
@@ -539,7 +549,7 @@ simulate_rules <- function(object,
                         tc_env[["SI_ud_history"]]  = ud_history
 
                         tcres =
-                           FM_tc(tc_env  = tc_env,
+                           formods::FM_tc(tc_env  = tc_env,
                                  capture = capture,
                                  cmd     = cmd)
 
@@ -571,7 +581,7 @@ simulate_rules <- function(object,
                         cmd  = paste0(c(cmd_init, preamble, rules[[rule_id]][["action"]][["code"]]), collapse="\n")
 
                         tcres =
-                          FM_tc(tc_env  = tc_env,
+                          formods::FM_tc(tc_env  = tc_env,
                                 capture = c("SI_interval_ev", "SI_ud_history"),
                                 cmd     = cmd)
                         if(tcres[["isgood"]]){
@@ -646,6 +656,12 @@ simulate_rules <- function(object,
                              cmt=rx_details[["elements"]][["outputs"]][1]))
 
             }
+
+            # Appending the subject level rule flags to the data frame for the event time
+            et_rule_flags = rbind(
+              et_rule_flags,
+              as.data.frame(sub_rule_flags)
+            )
           }
 
           # If an error has been encountered we just stop executing things
@@ -657,7 +673,7 @@ simulate_rules <- function(object,
                       preamble,
                       paste0("sim = rxode2::rxSolve(object, params=subjects, events=ev", rx_options_str, ")")),
                       collapse = "\n")
-            tcres = FM_tc(
+            tcres = formods::FM_tc(
               cmd     = sim_cmd,
               capture = c("sim"),
               tc_env  = list(object   = object,
@@ -675,10 +691,13 @@ simulate_rules <- function(object,
               fetch_rxtc(rx_details = rx_details,
                          sim        = tcres[["capture"]][["sim"]])
 
-              # Setting the rule flag for the presimulation
-              for(rule_id in names(rules)){
-                tmp_sim[[rule_id]] = sub_rule_flags[[rule_id]]
-              }
+              # Appending the rule flags for the current simulation interval 
+              tmp_sim = dplyr::left_join(tmp_sim, et_rule_flags, by=c(id="id"))
+
+              # # Setting the rule flag for the presimulation
+              # for(rule_id in names(rules)){
+              #   tmp_sim[[rule_id]] = sub_rule_flags[[rule_id]]
+              # }
 
               # We need to glue the simulations together. So first we remove the
               # last time point off of the simall data frame. The last time
@@ -1643,7 +1662,7 @@ rx2other <- function(object,
     allowed_out_types = c("nonmem", "monolix")
     if(out_type %in% allowed_out_types){
       # Checks here to determine if object is a valid nlmxir2 object:
-      tcres = FM_tc(
+      tcres = formods::FM_tc(
         cmd     = "rx_obj = rxode2::assertRxUi(object)",
         capture = c("rx_obj"),
         tc_env  = list(object   = object))
@@ -1660,7 +1679,7 @@ rx2other <- function(object,
             paste0("  rxode2::model({POP_RUMINATE <- exp(TV_RUMINATE+ ETA.RUMINATE)}, append=TRUE)  |>"),
             paste0("    rxode2::ini(TV_RUMINATE <-.1)"))
 
-          tcres = FM_tc(
+          tcres = formods::FM_tc(
             cmd     = paste0(cmds, collapse="\n"),
             capture = c("rx_obj"),
             tc_env  = list(rx_obj   = rx_obj))
@@ -1690,7 +1709,7 @@ rx2other <- function(object,
             paste0("           }, append=TRUE)  |>"),
             paste0("    rxode2::ini(add.OUT_RUMINTE <-.1)")
           )
-          tcres = FM_tc(
+          tcres = formods::FM_tc(
             cmd     = paste0(cmds, collapse="\n"),
             capture = c("rx_obj"),
             tc_env  = list(rx_obj   = rx_obj))
@@ -1757,8 +1776,8 @@ rx2other <- function(object,
         if(out_type == "nonmem"){
           #res = nlmixr2::nlmixr2(rx_obj, dataset, "nonmem",  babelmixr2::nonmemControl(modelName=export_name, runCommand=NA))
 
-          cmd = 'res = suppressMessages(suppressWarnings(nlmixr2::nlmixr2(rx_obj, dataset, "nonmem", babelmixr2::nonmemControl(modelName=export_name, runCommand=NA))))'
-          tcres = FM_tc(
+          cmd = 'res = suppressMessages(suppressWarnings(nlmixr2est::nlmixr2(rx_obj, dataset, "nonmem", babelmixr2::nonmemControl(modelName=export_name, runCommand=NA))))'
+          tcres = formods::FM_tc(
             cmd     = cmd,
             capture = c("res"),
             tc_env  = list(export_name   = export_name,
@@ -1779,8 +1798,8 @@ rx2other <- function(object,
         }
 
         if(out_type == "monolix"){
-          cmd = 'res = suppressMessages(suppressWarnings(nlmixr2::nlmixr2(rx_obj, dataset, "monolix", babelmixr2::monolixControl(modelName=export_name, runCommand=NA))))'
-          tcres = FM_tc(
+          cmd = 'res = suppressMessages(suppressWarnings(nlmixr2est::nlmixr2(rx_obj, dataset, "monolix", babelmixr2::monolixControl(modelName=export_name, runCommand=NA))))'
+          tcres = formods::FM_tc(
             cmd     = cmd,
             capture = c("res"),
             tc_env  = list(export_name   = export_name,
